/*
  Test program for StartUSB Board form USB HID with LabView
  Description : USB HID Controller
  MCU: PIC18F2550, External crystal = 8.0 MHz, Actual Clock = 48.0 MHz
  Copyright @ Eduardo Ludgero da Silva (NAES)
  17/10/2012
*/

//Clock
sbit Clock at RB1_bit;

/*
  USB Protocol
  char: 0..255 or 0x00..0xFF
  
  USB Read: Clock [vT0CON (char), vTMR0H (char), vTMR0L (char)];
  USB Write: Clock [vT0CON (char), vTMR0H (char), vTMR0L (char)];
*/

unsigned char readbuff[3] absolute 0x500;   //Buffers should be in USB RAM, please consult datasheet
unsigned char writebuff[3] absolute 0x510;

char i;
char vT0CON = 0x82;
char vTMR0H = 0x15;
char vTMR0L = 0x9F;

void InitTimer0(){
  T0CON = vT0CON;
  TMR0H = vTMR0H;
  TMR0L = vTMR0L;
  GIE_bit = 1;
  TMR0IE_bit = 1;
}

void Interrupt(){
  if (TMR0IF_bit){
    Clock = ~Clock;
    TMR0IF_bit = 0;
    TMR0H = vTMR0H;
    TMR0L = vTMR0H;
  }
  
  USB_Interrupt_Proc(); // USB servicing is done inside the interrupt
}


void main() {
     CMCON = 0x07;   //Disable comparators
     ADCON1 = 0x0F;  //Disable Analog functions
     
     TRISB = 0x00;   //Output port
     PORTB = 0x00;   //Set 0 bit portB

     Clock = 0;      //Set port Clock 0
     
     InitTimer0();
     
     HID_Enable(&readbuff,&writebuff);       // Enable HID communication
     Delay_5ms();

do{
    while(!HID_Read());
    
    vT0CON = readbuff[0];
    vTMR0H = readbuff[1];
    vTMR0L = readbuff[2];
    InitTimer0();
       
    for(i=0; i<3; i++){
       writebuff[i] = readbuff[i];
    }
    
    while(!HID_Write(&writebuff,3));

 }while(1);
}